// _GPIO_old.c
// Runs on TM4C1294
// Initialize four GPIO pins as outputs.  Continually generate output to
// drive simulated stepper motor.
// This deprecated version actually flashes the LEDs on the Connected
// Launchpad, but due to the inconvenient pin connections of the LEDs,
// this version is unacceptably different from the book example.
// Daniel Valvano
// April 3, 2014

/* This example accompanies the books
   "Embedded Systems: Introduction to ARM Cortex M Microcontrollers",
   ISBN: 978-1469998749, Jonathan Valvano, copyright (c) 2014
   Volume 1 Program 4.5

   "Embedded Systems: Real Time Interfacing to ARM Cortex M Microcontrollers",
   ISBN: 978-1463590154, Jonathan Valvano, copyright (c) 2014
   Volume 2 Example 2.2, Program 2.8, Figure 2.32

 Copyright 2014 by Jonathan W. Valvano, valvano@mail.utexas.edu
    You may use, edit, run or distribute this file
    as long as the above copyright notice remains
 THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 VALVANO SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 For more information about my classes, my research, and my books, see
 http://users.ece.utexas.edu/~valvano/
 */

// PF0 is an output to positive logic LED4
// PF4 is an output to positive logic LED3
// PN0 is an output to positive logic LED2
// PN1 is an output to positive logic LED1

#define LED43                   (*((volatile unsigned long *)0x4005D044))
#define LED4                    0x01
#define LED3                    0x10
#define GPIO_PORTF_DIR_R        (*((volatile unsigned long *)0x4005D400))
#define GPIO_PORTF_AFSEL_R      (*((volatile unsigned long *)0x4005D420))
#define GPIO_PORTF_DEN_R        (*((volatile unsigned long *)0x4005D51C))
#define GPIO_PORTF_AMSEL_R      (*((volatile unsigned long *)0x4005D528))
#define GPIO_PORTF_PCTL_R       (*((volatile unsigned long *)0x4005D52C))
#define LED21                   (*((volatile unsigned long *)0x4006400C))
#define LED2                    0x01
#define LED1                    0x02
#define GPIO_PORTN_DIR_R        (*((volatile unsigned long *)0x40064400))
#define GPIO_PORTN_AFSEL_R      (*((volatile unsigned long *)0x40064420))
#define GPIO_PORTN_DEN_R        (*((volatile unsigned long *)0x4006451C))
#define GPIO_PORTN_AMSEL_R      (*((volatile unsigned long *)0x40064528))
#define GPIO_PORTN_PCTL_R       (*((volatile unsigned long *)0x4006452C))
#define SYSCTL_RCGCGPIO_R       (*((volatile unsigned long *)0x400FE608))
#define SYSCTL_RCGCGPIO_R12     0x00001000  // GPIO Port N Run Mode Clock
                                            // Gating Control
#define SYSCTL_RCGCGPIO_R5      0x00000020  // GPIO Port F Run Mode Clock
                                            // Gating Control
#define SYSCTL_PRGPIO_R         (*((volatile unsigned long *)0x400FEA08))
#define SYSCTL_PRGPIO_R12       0x00001000  // GPIO Port N Peripheral Ready
#define SYSCTL_PRGPIO_R5        0x00000020  // GPIO Port F Peripheral Ready

void GPIO_Init(void){
                                   // activate clock for Port F
  SYSCTL_RCGCGPIO_R |= SYSCTL_RCGCGPIO_R5;
                                   // allow time for clock to stabilize
  while((SYSCTL_PRGPIO_R&SYSCTL_PRGPIO_R5) == 0){};
  GPIO_PORTF_DIR_R |= 0x11;        // make PF4,0 out (PF4,0 built-in LED3-4)
  GPIO_PORTF_AFSEL_R &= ~0x11;     // disable alt funct on PF4,0
  GPIO_PORTF_DEN_R |= 0x11;        // enable digital I/O on PF4,0
                                   // configure PF4,0 as GPIO
  GPIO_PORTF_PCTL_R = (GPIO_PORTF_PCTL_R&0xFFF0FFF0)+0x00000000;
  GPIO_PORTF_AMSEL_R &= ~0x11;     // disable analog functionality on PF4,0
                                   // activate clock for Port N
  SYSCTL_RCGCGPIO_R |= SYSCTL_RCGCGPIO_R12;
                                   // allow time for clock to stabilize
  while((SYSCTL_PRGPIO_R&SYSCTL_PRGPIO_R12) == 0){};
  GPIO_PORTN_DIR_R |= 0x03;        // make PN1-0 out (PN1-0 built-in LED1-2)
  GPIO_PORTN_AFSEL_R &= ~0x03;     // disable alt funct on PN1-0
  GPIO_PORTN_DEN_R |= 0x03;        // enable digital I/O on PN1-0
                                   // configure PN1-0 as GPIO
  GPIO_PORTN_PCTL_R = (GPIO_PORTN_PCTL_R&0xFFFFFF00)+0x00000000;
  GPIO_PORTN_AMSEL_R &= ~0x03;     // disable analog functionality on PN1-0
}

int main(void){
  GPIO_Init();
  while(1){
    LED43 = LED3; LED21 = LED1;    // 0101
    LED43 = LED3; LED21 = LED2;    // 0110
    LED43 = LED4; LED21 = LED2;    // 1010
    LED43 = LED4; LED21 = LED1;    // 1010
  }
}
